==> gcstar_0.5.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/ES/GCModels/GCfilms.pm <==
{
    package GCLang::ES::GCModels::GCfilms;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Movies collection',
        Items => 'Películas',
        NewItem => 'Nueva película',
    
    
        Id => 'Id',
        Title => 'Título',
        Date => 'Fecha de salida',
        Time => 'Duración',
        Director => 'Director',
        Country => 'Nacionalidad',
        MinimumAge => 'Edad mínima',
        Genre => 'Géneros',
        Image => 'Imagen',
        Original => 'Título original',
        Actors => 'Actores',
        Comment => 'Comentarios',
        Synopsis => 'Sinopsis',
        Seen => 'Ya vista',
        Number => 'Número',
        Rating => 'Nota',
        Format => 'Soporte',
        Url => 'URL',
        Place => 'Sitio',
        Audio => 'Audio',
        Video => 'Formato de video',
        Trailer => 'Fichero de video',
        Serie => 'Serie',
        Rank => 'Capítulo',
        Subtitles => 'Subtítulos',

        SeenYes => 'Película ya vista',
        SeenNo => 'Película no vista',

        AgeUnrated => 'Desconocida',
        AgeAll => 'Ninguna',
        AgeParent => 'Control paterno',

        Main => 'Elementos principales',
        General => 'Ficha de la película',
        Details => 'Información personal',
        Lending => 'Préstamo',

        Information => 'Informacion',
        Languages => 'Idiomas',
        Encoding => 'Codificación',

        FilterAudienceAge => 'Edad mínima',
        FilterSeenNo => 'Películas no vistas',
        FilterSeenYes => '_Already Viewed',
        FilterRatingSelect => 'Notas al menos iguales a...',
     );
}

1;

==> gcstar_1.0.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/ES/GCModels/GCfilms.pm <==
{
    package GCLang::ES::GCModels::GCfilms;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Colección de películas',
        Items => 'Películas',
        NewItem => 'Nueva película',
    
    
        Id => 'Id',
        Title => 'Título',
        Date => 'Fecha de salida',
        Time => 'Duración',
        Director => 'Director',
        Country => 'Nacionalidad',
        MinimumAge => 'Edad mínima',
        Genre => 'Géneros',
        Image => 'Imagen',
        Original => 'Título original',
        Actors => 'Actores',
        Comment => 'Comentarios',
        Synopsis => 'Sinopsis',
        Seen => 'Ya vista',
        Number => 'Número',
        Rating => 'Nota',
        Format => 'Soporte',
        Url => 'URL',
        Place => 'Sitio',
        Audio => 'Audio',
        Video => 'Formato de video',
        Trailer => 'Fichero de video',
        Serie => 'Serie',
        Rank => 'Capítulo',
        Subtitles => 'Subtítulos',
        Added => 'Añadida el (fecha)',

        SeenYes => 'Película ya vista',
        SeenNo => 'Película no vista',

        AgeUnrated => 'Desconocida',
        AgeAll => 'Ninguna',
        AgeParent => 'Control paterno',

        Main => 'Elementos principales',
        General => 'Ficha de la película',
        Details => 'Información personal',
        Lending => 'Préstamo',

        Information => 'Informacion',
        Languages => 'Idiomas',
        Encoding => 'Codificación',

        FilterAudienceAge => 'Edad mínima',
        FilterSeenNo => 'Películas no vistas',
        FilterSeenYes => '_Ya vista',
        FilterRatingSelect => 'Puntuación al _menos...',

        ExtractSize => 'Tamaño',
     );
}

1;
